@@ -12,15 +12,15 @@ const our $TLS_CTX_LOW  => 0;
 const our $TLS_CTX_HIGH => 1;
 const our $TLS_CTX      => {
     $TLS_CTX_LOW => {
-        ca_file         => P->ca->ca_file,
+        $MSWIN ? ( ca_file => P->ca->ca_file ) : (),
         cache           => 1,
         verify          => 0,
         verify_peername => undef,
         sslv2           => 1,
-        dh              => undef,            # Diffie-Hellman is disabled
+        dh              => undef,    # Diffie-Hellman is disabled
     },
     $TLS_CTX_HIGH => {
-        ca_file         => P->ca->ca_file,
+        $MSWIN ? ( ca_file => P->ca->ca_file ) : (),
         cache           => 1,
         verify          => 1,
         verify_peername => 'http',
