@@ -1,24 +1,21 @@
 package Pcore::Dist::CLI;
 
 use Pcore -role;
-use Pcore::Dist;
 
 with qw[Pcore::Core::CLI::Cmd];
 
-has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'], init_arg => undef );
+sub get_dist ($self) {
+    require Pcore::Dist;
 
-around run => sub ( $orig, $self, @args ) {
     if ( my $dist = Pcore::Dist->new( $ENV->{START_DIR} ) ) {
-        $self->{dist} = $dist;
+        return $dist;
     }
     else {
         say 'Pcore distribution was not found' . $LF;
 
         exit 3;
     }
-
-    return $self->$orig(@args);
-};
+}
 
 1;
 __END__
